translate.convert.ical2po

Package translate :: Package convert :: Module ical2po |
[hide private]
[frames] | no frames]

# Module ical2po

source code

convert iCal files to Gettext PO localization files

Classes | [hide private]
| ical2po convert a iCal file to a .po file for handling the translation...

Functions | [hide private]
convertical(input_file, output_file, template_file, pot=False, duplicatestyle="msgctxt") Reads in `input_file` using iCal, converts using ical2po, writes to `output_file` | source code
main(argv=None) | source code

Imports: sys, po, ical